"""Add value to energyprice.

Revision ID: 668759e73b80
Revises: 46adf5114de1
Create Date: 2017-08-22 13:34:08.196691

"""
from alembic import op
import sqlalchemy as sa

# revision identifiers, used by Alembic.
revision = '668759e73b80'
down_revision = '46adf5114de1'


def upgrade():
    for column in ('value', 'bill', 'usage_hauptzaehler',
                   'usage_members', 'leakage_current'):
        op.add_column('energyprice',
                      sa.Column(column, sa.Integer(), nullable=True))
    op.execute("""
        UPDATE energyprice
            SET value = 1489550,
                bill = 114392300
            WHERE year = 2016""")


def downgrade():
    op.drop_column('energyprice', 'value')



"""Add SEPA Sammelueberweisung

Revision ID: e47f78fad78f
Revises: 98db6b34d1a3
Create Date: 2020-01-16 08:01:46.509668

"""
from alembic import op
import sqlalchemy as sa

# revision identifiers, used by Alembic.
revision = 'e47f78fad78f'
down_revision = '98db6b34d1a3'


def upgrade():
    op.add_column(
        'sepasammler',
        sa.Column(
            'is_ueberweisung',
            sa.Boolean(),
            nullable=False,
            server_default='False',
        )
    )


def downgrade():
    op.drop_column('sepasammler', 'is_ueberweisung')



"""re #2: Add model for prices of energvalues.

Revision ID: 56e61da4fed1
Revises: 447579f29e92
Create Date: 2014-12-21 16:33:28.811658

"""
from alembic import op
import sqlalchemy as sa

# revision identifiers, used by Alembic.
revision = '56e61da4fed1'
down_revision = '447579f29e92'


def upgrade():
    op.create_table(
        'energyprice',
        sa.Column('id', sa.Integer(), nullable=False),
        sa.Column('year', sa.Integer(), nullable=True),
        sa.Column('price', sa.Integer(), nullable=True),
        sa.PrimaryKeyConstraint('id')
    )
    op.execute("""INSERT into energyprice (year, price) VALUES (2014, 30);""")


def downgrade():
    op.drop_table('energyprice')



"""Add sepa sammler helper data.

Revision ID: 17b7b9cfd7e8
Revises: 41e271c4e3e8
Create Date: 2015-03-31 17:30:48.572311

"""

# revision identifiers, used by Alembic.
from alembic import op
import sqlalchemy as sa

revision = '17b7b9cfd7e8'
down_revision = '41e271c4e3e8'


def upgrade():
    op.create_table(
        'sepasammler',
        sa.Column('id', sa.Integer(), nullable=False),
        sa.Column('pmtinfid', sa.String(length=100), nullable=True),
        sa.Column('member_id', sa.Integer(), nullable=True),
        sa.Column('kind_id', sa.Integer(), nullable=True),
        sa.Column('value', sa.Integer(), nullable=True),
        sa.ForeignKeyConstraint(['kind_id'], [u'bookingkind.id'], ),
        sa.ForeignKeyConstraint(['member_id'], [u'member.id'], ),
        sa.PrimaryKeyConstraint('id')
    )


def downgrade():
    op.drop_table('sepasammler')



"""re #28: Save message tag instead of Message-ID.

Revision ID: 3b50f99a2e2f
Revises: ff1bb01af7fa
Create Date: 2016-11-23 09:24:49.794794

"""
# revision identifiers, used by Alembic.
from alembic import op
import sqlalchemy as sa

revision = '3b50f99a2e2f'
down_revision = 'ff1bb01af7fa'


def upgrade():
    op.add_column('sentmessageinfo',
                  sa.Column('tag', sa.String(length=100), nullable=True))
    op.drop_column('sentmessageinfo', 'msg_id')


def downgrade():
    op.add_column('sentmessageinfo',
                  sa.Column('msg_id', sa.VARCHAR(length=100),
                            autoincrement=False, nullable=True))
    op.drop_column('sentmessageinfo', 'tag')



"""re #2: Model for electic meter and energy value.

Revision ID: 447579f29e92
Revises: 51143cacbf85
Create Date: 2014-12-19 20:58:40.738035

"""
from alembic import op
import sqlalchemy as sa

# revision identifiers, used by Alembic.
revision = '447579f29e92'
down_revision = '51143cacbf85'


def upgrade():
    op.execute('INSERT into allotment (number, member_id) VALUES (311, 138);')
    op.execute('INSERT into allotment (number, member_id) VALUES (222, 104);')
    op.execute('INSERT into allotment (number, member_id) VALUES (249, 129);')
    op.execute('INSERT into allotment (number, member_id) VALUES (316, 175);')
    op.execute('INSERT into allotment (number, member_id) VALUES (232, 173);')
    op.execute('INSERT into allotment (number, member_id) VALUES (334, 177);')
    op.create_table(
        'electricmeter',
        sa.Column('id', sa.Integer(), nullable=False),
        sa.Column('allotment_id', sa.Integer(), nullable=False),
        sa.Column('number', sa.String(), nullable=True),
        sa.Column('electric_power', sa.Boolean(), nullable=True),
        sa.Column('disconnected', sa.Boolean(), nullable=True),
        sa.Column('replaced_by_id', sa.Integer(), nullable=True),
        sa.ForeignKeyConstraint(['allotment_id'], [u'allotment.id'], ),
        sa.ForeignKeyConstraint(['replaced_by_id'], [u'electricmeter.id'], ),
        sa.PrimaryKeyConstraint('id')
    )
    op.create_table(
        'energyvalue',
        sa.Column('id', sa.Integer(), nullable=False),
        sa.Column('electric_meter_id', sa.Integer(), nullable=False),
        sa.Column('year', sa.Integer(), nullable=True),
        sa.Column('value', sa.Integer(), nullable=True),
        sa.ForeignKeyConstraint(['electric_meter_id'], [u'electricmeter.id']),
        sa.PrimaryKeyConstraint('id')
    )


def downgrade():
    op.drop_table('energyvalue')
    op.drop_table('electricmeter')
